@@ -76,7 +76,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = test$method
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -123,7 +123,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "Shapiro - Wilk Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -196,8 +196,8 @@ function(x, title = NULL, description = NULL)
         data.name = DNAME)
 
     # Add:
-    if (is.null(title)) title = "Jarque - Bera Normalality Test"
-    if (is.null(description)) description = description()
+    if (is.null(title)) title = "Jarque-Bera Normality Test"
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -294,7 +294,12 @@ function(x)
     B = (6*(n*n-5*n+2)/((n+7)*(n+9)))*sqrt((6*(n+3)*(n+5))/(n*(n-2)*(n-3)))
     A = 6+(8/B)*((2/B)+sqrt(1+4/(B**2)))
     jm = sqrt(2/(9*A))
-    pos = ((1-2/A)/(1+U4*sqrt(2/(A-4))))**(1/3)
+    ## (2023-02-27) Georgi: 'pos' becomes NaN for a power of negative number, reported by
+    ##         Cameron Wilden. Implementing his suggestion for fix.
+    ## was: pos = ((1-2/A)/(1+U4*sqrt(2/(A-4))))**(1/3)
+    pos0 = ((1-2/A)/(1+U4*sqrt(2/(A-4))))
+    pos <- sign(pos0) * abs(pos0) ^ (1/3)
+
     Z4 = (1-2/(9*A)-pos)/jm
     pZ4 = 2*(1-pnorm(abs(Z4),0,1))
     names(Z4) = "Z4"
@@ -347,7 +352,11 @@ function(x)
     B = (6*(n*n-5*n+2)/((n+7)*(n+9)))*sqrt((6*(n+3)*(n+5))/(n*(n-2)*(n-3)))
     A = 6+(8/B)*((2/B)+sqrt(1+4/(B**2)))
     jm = sqrt(2/(9*A))
-    pos = ((1-2/A)/(1+U4*sqrt(2/(A-4))))**(1/3)
+    ## Georgi: see similar change in .kurtosis.test()
+    ## was: pos = ((1-2/A)/(1+U4*sqrt(2/(A-4))))**(1/3)
+    pos0 = ((1-2/A)/(1+U4*sqrt(2/(A-4))))
+    pos <- sign(pos0) * abs(pos0) ^ (1/3)
+
     Z4 = (1-2/(9*A)-pos)/jm
     omni = Z3**2+Z4**2
     pomni = 1-pchisq(omni,2)
@@ -421,7 +430,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "D'Agostino Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -567,7 +576,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "Anderson - Darling Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     ans = new("fHTEST",
@@ -653,7 +662,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "Cramer - von Mises Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -750,7 +759,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "Lilliefors (KS) Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -843,7 +852,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "Pearson Chi-Square Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -920,7 +929,7 @@ function(x, title = NULL, description = NULL)
 
     # Add:
     if (is.null(title)) title = "Shapiro - Francia Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
@@ -1051,7 +1060,7 @@ function(x, title = NULL, description = NULL)
 
     # Add Title:
     if (is.null(title)) title = "Jarque - Bera Normality Test"
-    if (is.null(description)) description = description()
+    if (is.null(description)) description = ""
 
     # Return Value:
     new("fHTEST",
